# dpyrandmeme: random memes for discord.py


**What does the library do?**
This library simply uses aiohttp to collect json data from a reddit page and turns it into a link inorder to be used while also storing the memes and returning the meme as a discord embed before sending back to the discord bot to send to the member who sent that command. It is the same meme library that is currently being used inside Paradigm.

**PyPi library link:**
https://pypi.org/project/dpyrandmeme/

**Credits:**

d33pak123: https://github.com/d33pak123/Pyrandmeme-python-library, <br>
and Microsoft for the template
